@@ -60,17 +60,13 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
       //Check whether we need to add SLOT( or SIGNAL(
       QString prefixText = document->text(KTextEditor::Range(word.start().line(), 0, word.start().line(), word.start().column()));
       kDebug() << "prefix" << prefixText;
-      QRegExp signalRegExp("(Q_)*SIGNAL(\\s)*\\(");
-      QRegExp slotRegExp("(Q_)*SLOT(\\s)*\\(");
-      int signalAt = signalRegExp.lastIndexIn(prefixText);
-      kDebug() << "signalRegExp found at" << signalAt;
-      if(signalAt != -1 && prefixText.mid(signalAt + signalRegExp.matchedLength()).trimmed().isEmpty())
-        addSignalSlot = false;
-      int slotAt = slotRegExp.lastIndexIn(prefixText);
-      if(slotAt != -1 && prefixText.mid(slotAt + slotRegExp.matchedLength()).trimmed().isEmpty())
+      QRegExp signalSlotRegExp("(Q_)?(SIGNAL|SLOT)\\s*\\(");
+      int signalSlotAt = signalSlotRegExp.lastIndexIn(prefixText);
+      kDebug() << "signalSlotRegExp found at" << signalSlotAt;
+      if(signalSlotAt != -1 && prefixText.mid(signalSlotAt + signalSlotRegExp.matchedLength()).trimmed().isEmpty())
         addSignalSlot = false;
     }
-    
+
     KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
     QString functionSignature;
     Cpp::QtFunctionDeclaration* classFun = dynamic_cast<Cpp::QtFunctionDeclaration*>(m_declaration.data());
@@ -89,7 +85,24 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
       }
     }
     lock.unlock();
-    document->replaceText(word, functionSignature);
+
+    int extendRange = 0;
+    {
+      //Check whether we need to remove existing stuff
+      //note: it might be that the identifier (e.g. Q_SIGNAL) is already included in
+      //the word, so be pretty forgiving in the regexp
+      const QString line = document->text(KTextEditor::Range(word.end().line(), word.end().column(),
+                                                       word.end().line(), document->lineLength(word.end().line())));
+      QRegExp existingRegExp("^\\s*((Q_)?(SIGNAL|SLOT)\\s*)?\\([^\\)]*\\s*\\)\\s*\\)");
+      int from = line.indexOf(existingRegExp);
+      if (from != -1) {
+          extendRange = existingRegExp.matchedLength();
+      }
+    }
+
+    document->replaceText(KTextEditor::Range(word.start().line(), word.start().column(),
+                                             word.end().line(), word.end().column() + extendRange),
+                          functionSignature);
     return;
   }
   
