@@ -19,8 +19,6 @@
 #include "makeimplementationprivate.h"
 #include "ui_privateimplementation.h"
 
-#include "cpputils.h"
-
 #include "cppduchain/sourcemanipulation.h"
 #include "cppnewclass.h"
 #include <cppeditorintegrator.h>
@@ -50,6 +48,20 @@
 namespace KDevelop
 {
 
+/**
+ * @param objectToAllocate The declaration of the object to allocate memory for
+ * @return the stringirized form of the user's preferred method of mamory allocation
+ */
+QString insertMemoryAllocation(const KDevelop::Declaration & objectToAllocate)
+{
+  return "new " + objectToAllocate.toString();
+}
+
+QString insertMemoryDeallocation(const KDevelop::Declaration& objectToDeallocate)
+{
+  return "delete " + objectToDeallocate.toString();
+}
+
 bool MakeImplementationPrivate::process()
 {
     //If invoked through auto generation, then gatherPrivateMembers wan't called
@@ -354,7 +366,7 @@ void MakeImplementationPrivate::updateConstructors(const Declaration & privateSt
             }
             else
               insertionPoint = integrator.findPosition(construct->constructor_initializers->colon);
-            insertedText += " " + m_privatePointerName + "(" + CppUtils::insertMemoryAllocation(privateStruct) + ") ";
+            insertedText += " " + m_privatePointerName + "(" + insertMemoryAllocation(privateStruct) + ") ";
             
             DocumentChange constructorChange(constructor->url(), SimpleRange(insertionPoint, 0), QString(), insertedText);
             documentChangeSet().addChange(constructorChange);
@@ -421,7 +433,7 @@ void MakeImplementationPrivate::updateDestructor()
         if(inside.column > 0)
             inside.column = inside.column - 1;
         DocumentChange destructorChange(internal->url(), SimpleRange(inside, 0),
-                                        QString(), /*CppUtils::insertMemoryDeallocation()*/ "delete this->" + m_privatePointerName + ";\n");
+                                        QString(), "delete this->" + m_privatePointerName + ";\n");
     
         documentChangeSet().addChange(destructorChange);
     }
