@@ -121,23 +121,26 @@ void SimpleRefactoring::doContextMenu(KDevelop::ContextMenuExtension& extension,
     Declaration* declaration = declContext->declaration().data();
 
     if(declaration) {
-      QAction* action = new QAction(i18n("Rename %1", declaration->qualifiedIdentifier().toString()), this);
-      action->setData(QVariant::fromValue(IndexedDeclaration(declaration)));
-      action->setIcon(KIcon("edit-rename"));
-      connect(action, SIGNAL(triggered(bool)), this, SLOT(executeRenameAction()));
+      QFileInfo finfo(declaration->topContext()->url().str());
+      if (finfo.isWritable()) {
+        QAction* action = new QAction(i18n("Rename %1", declaration->qualifiedIdentifier().toString()), this);
+        action->setData(QVariant::fromValue(IndexedDeclaration(declaration)));
+        action->setIcon(KIcon("edit-rename"));
+        connect(action, SIGNAL(triggered(bool)), this, SLOT(executeRenameAction()));
 
-      extension.addAction(ContextMenuExtension::RefactorGroup, action);
-      
-      if(declContext->use().isEmpty() && declaration->isFunctionDeclaration() && declaration->internalContext() && declaration->internalContext()->type() == DUContext::Other &&
-        !dynamic_cast<Cpp::TemplateDeclaration*>(declaration)) {
-        AbstractFunctionDeclaration* funDecl = dynamic_cast<AbstractFunctionDeclaration*>(declaration);
-        if(funDecl && !funDecl->isInline() && !dynamic_cast<FunctionDefinition*>(funDecl)) {
-          //Is a candidate for moving into source
-          QAction* action = new QAction(i18n("Create separate definition for %1", declaration->qualifiedIdentifier().toString()), this);
-          action->setData(QVariant::fromValue(IndexedDeclaration(declaration)));
+        extension.addAction(ContextMenuExtension::RefactorGroup, action);
+
+        if(declContext->use().isEmpty() && declaration->isFunctionDeclaration() && declaration->internalContext() && declaration->internalContext()->type() == DUContext::Other &&
+          !dynamic_cast<Cpp::TemplateDeclaration*>(declaration)) {
+          AbstractFunctionDeclaration* funDecl = dynamic_cast<AbstractFunctionDeclaration*>(declaration);
+          if(funDecl && !funDecl->isInline() && !dynamic_cast<FunctionDefinition*>(funDecl)) {
+            //Is a candidate for moving into source
+            QAction* action = new QAction(i18n("Create separate definition for %1", declaration->qualifiedIdentifier().toString()), this);
+            action->setData(QVariant::fromValue(IndexedDeclaration(declaration)));
 //           action->setIcon(KIcon("arrow-right"));
-          connect(action, SIGNAL(triggered(bool)), this, SLOT(executeMoveIntoSourceAction()));
-          extension.addAction(ContextMenuExtension::RefactorGroup, action);
+            connect(action, SIGNAL(triggered(bool)), this, SLOT(executeMoveIntoSourceAction()));
+            extension.addAction(ContextMenuExtension::RefactorGroup, action);
+          }
         }
       }
     }
@@ -194,7 +197,7 @@ void SimpleRefactoring::createNewClass(ProjectBaseItem* item)
     IProject* p=item->project();
     ProjectFolderItem* folder=item->folder();
     ProjectTargetItem* target=item->target();
-    
+
     if(target) {
       folder=static_cast<ProjectFolderItem*>(item->target()->parent());
       Q_ASSERT(folder->folder());
@@ -214,10 +217,9 @@ void SimpleRefactoring::createNewClass(ProjectBaseItem* item)
         KDevelop::ProjectBaseItem* bit=static_cast<KDevelop::ProjectBaseItem*>(it);
         t=bit->targetList();
       }
-      
       if(t.count()==1) //Just choose this one
         target=t.first();
-      else {
+      else if(t.count() > 1) {
         KDialog d;
         QWidget *w=new QWidget(&d);
         w->setLayout(new QVBoxLayout);
@@ -242,24 +244,38 @@ void SimpleRefactoring::createNewClass(ProjectBaseItem* item)
         }
       }
     }
-    
-    if(folder && p->projectFileManager())
-    {
-      ProjectFileItem* file=p->projectFileManager()->addFile(newClassWizard.implementationUrl(), folder);
-      ProjectFileItem* header=p->projectFileManager()->addFile(newClassWizard.headerUrl(), folder);
 
-      if(target && p->buildSystemManager())
-      {
-        if(file)
-          p->buildSystemManager()->addFileToTarget(file, target);
-        else
-          kWarning() << "Could not add source file to build manager" << newClassWizard.implementationUrl();
-        
-        if(header)
-          p->buildSystemManager()->addFileToTarget(header, target);
-        else
-          kWarning() << "Could not add header file to build-manager" << newClassWizard.headerUrl();
+    if(target && p->buildSystemManager())
+    {
+      ProjectFileItem* file = 0;
+      ProjectFileItem* header = 0;
+
+      // usually the filemanager will have added these files automatically
+      // if not, do it manually
+      QList< ProjectFileItem* > matches = p->filesForUrl(newClassWizard.implementationUrl());
+      if (!matches.isEmpty()) {
+        file = matches.first();
+      } else if (p->projectFileManager()) {
+        ///TODO: this case will still show the "file already exists" error message
+        file = p->projectFileManager()->addFile(newClassWizard.implementationUrl(), folder);
       }
+      matches = p->filesForUrl(newClassWizard.headerUrl());
+      if (!matches.isEmpty()) {
+        header = matches.first();
+      } else if (p->projectFileManager()) {
+        ///TODO: this case will still show the "file already exists" error message
+        header = p->projectFileManager()->addFile(newClassWizard.headerUrl(), folder);
+      }
+
+      if(file)
+        p->buildSystemManager()->addFileToTarget(file, target);
+      else
+        kWarning() << "Could not add source file to build manager" << newClassWizard.implementationUrl();
+      
+      if(header)
+        p->buildSystemManager()->addFileToTarget(header, target);
+      else
+        kWarning() << "Could not add header file to build-manager" << newClassWizard.headerUrl();
     }
   }
 }
@@ -381,6 +397,9 @@ void SimpleRefactoring::executeRenameAction() {
 class SimpleRefactoringCollector : public KDevelop::UsesWidget::UsesWidgetCollector {
   public:
   SimpleRefactoringCollector(IndexedDeclaration decl) : UsesWidgetCollector(decl) {
+    setCollectConstructors(true);
+    setCollectDefinitions(true);
+    setCollectOverloads(true);
   }
 
   virtual void processUses(KDevelop::ReferencedTopDUContext topContext) {
@@ -449,6 +468,12 @@ void SimpleRefactoring::startInteractiveRename(KDevelop::IndexedDeclaration decl
     KMessageBox::error(ICore::self()->uiController()->activeMainWindow(), i18n("No declaration under cursor"));
     return;
   }
+  QFileInfo info(declaration->topContext()->url().str());
+  if (!info.isWritable()) {
+    KMessageBox::error(ICore::self()->uiController()->activeMainWindow(),
+                       i18n("Declaration is located in non-writeable file %1.", declaration->topContext()->url().str()));
+    return;
+  }
 
   if(FunctionDefinition* definition = dynamic_cast<FunctionDefinition*>(declaration))
     declaration = definition->declaration(declaration->topContext());
