@@ -392,12 +392,13 @@ QString preprocess( const QString& text, Cpp::EnvironmentFile* file, int line, Q
 
   {
       DUChainReadLocker lock(DUChain::lock());
-/*    kDebug(9007) << "defined macros: " << file->definedMacros().size();*/
     //Copy in all macros from the file
     for( Cpp::ReferenceCountedMacroSet::Iterator it( file->definedMacros().iterator() ); it; ++it ) {
       if( line == -1 || line > it.ref().sourceLine || file->url() != it.ref().file ) {
         if(!disableMacros.contains( it.ref().name ))
+        {
           pp.environment()->setMacro( new rpp::pp_macro(it.ref()) );
+        }
       }
     }
     for( Cpp::ReferenceCountedMacroSet::Iterator it( file->usedMacros().iterator() ); it; ++it ) {
@@ -794,16 +795,21 @@ QualifiedIdentifier stripPrefixes(DUContext* ctx, QualifiedIdentifier id)
   if(!ctx)
     return id;
   
+  QualifiedIdentifier basicId = id;
+  
   QList<QualifiedIdentifier> imports = ctx->fullyApplyAliases(QualifiedIdentifier(), ctx->topContext());
   if(imports.contains(id))
     return QualifiedIdentifier(); ///The id is a namespace that is imported into the current context
   
-  QList< Declaration* > basicDecls = ctx->findDeclarations(id, SimpleCursor::invalid(), AbstractType::Ptr(), 0, DUContext::NoSelfLookUp);
+  QList< Declaration* > basicDecls = ctx->findDeclarations(id, SimpleCursor::invalid(), AbstractType::Ptr(), 0, (DUContext::SearchFlags)(DUContext::NoSelfLookUp | DUContext::NoFiltering));
+  
+  if(basicDecls.isEmpty())
+    return id;
   
   while(!id.isEmpty())
   {
     QualifiedIdentifier newId = id.mid(1);
-    QList< Declaration* > foundDecls = ctx->findDeclarations(newId, SimpleCursor::invalid(), AbstractType::Ptr(), 0, DUContext::NoSelfLookUp);
+    QList< Declaration* > foundDecls = ctx->findDeclarations(newId, SimpleCursor::invalid(), AbstractType::Ptr(), 0, (DUContext::SearchFlags)(DUContext::NoSelfLookUp | DUContext::NoFiltering));
     
     if(foundDecls == basicDecls)
       id = newId;
