@@ -162,13 +162,11 @@ Declaration* TestExpressionParser::findDeclaration(DUContext* context, const Qua
 }
 
 void TestExpressionParser::testIntegralType() {
-  QByteArray type("const char*");
-  DUContext* top = parse(type, DumpNone);
-  
+  DUContext* top = parse(" ", DumpNone);
   Cpp::ExpressionParser parser(true,true);
 
   {
-    Cpp::ExpressionEvaluationResult result = parser.evaluateType(type, KDevelop::DUContextPointer(top));
+    Cpp::ExpressionEvaluationResult result = parser.evaluateType("const char*", KDevelop::DUContextPointer(top));
     QVERIFY(result.isValid());
     
     AbstractType::Ptr aType(result.type.abstractType());
@@ -181,10 +179,50 @@ void TestExpressionParser::testIntegralType() {
     IntegralType::Ptr iBaseType = aBaseType.cast<IntegralType>();
     QVERIFY(iBaseType);
     QCOMPARE(iBaseType->dataType(), (uint)IntegralType::TypeChar);
-    
-    /// FIXME: This currently fails.
+
     QVERIFY(iBaseType->modifiers() & IntegralType::ConstModifier);
   }
+  {
+    Cpp::ExpressionEvaluationResult result = parser.evaluateType("'x'", KDevelop::DUContextPointer(top));
+    QVERIFY(result.isValid());
+    
+    AbstractType::Ptr aType(result.type.abstractType());
+    ConstantIntegralType::Ptr ciType = aType.cast<ConstantIntegralType>();
+    QVERIFY(ciType);
+    QCOMPARE(ciType->dataType(), (uint)ConstantIntegralType::TypeChar);
+    QCOMPARE(ciType->value<char>(), 'x');
+  }
+  {
+      Cpp::ExpressionEvaluationResult result = parser.evaluateType("5", KDevelop::DUContextPointer(top));
+      QVERIFY(result.isValid());
+      
+      AbstractType::Ptr aType(result.type.abstractType());
+      ConstantIntegralType::Ptr ciType = aType.cast<ConstantIntegralType>();
+      QVERIFY(ciType);
+      QCOMPARE(ciType->dataType(), (uint)ConstantIntegralType::TypeInt);
+      QCOMPARE(ciType->value<int>(), 5);
+  }
+  {
+    Cpp::ExpressionEvaluationResult result = parser.evaluateType("true", KDevelop::DUContextPointer(top));
+    QVERIFY(result.isValid());
+    
+    AbstractType::Ptr aType(result.type.abstractType());
+    ConstantIntegralType::Ptr ciType = aType.cast<ConstantIntegralType>();
+    QVERIFY(ciType);
+    QCOMPARE(ciType->dataType(), (uint)ConstantIntegralType::TypeBoolean);
+    QCOMPARE(ciType->value<bool>(), true);
+  }
+  {
+    Cpp::ExpressionEvaluationResult result = parser.evaluateType("'\n'", KDevelop::DUContextPointer(top));
+    QVERIFY(result.isValid());
+    
+    AbstractType::Ptr aType(result.type.abstractType());
+    ConstantIntegralType::Ptr ciType = aType.cast<ConstantIntegralType>();
+    QVERIFY(ciType);
+    QCOMPARE(ciType->dataType(), (uint)ConstantIntegralType::TypeChar);
+    QEXPECT_FAIL("", "store values for chars of escape sequences in ExpressionVisitor::visitPrimaryExpression", Continue);
+    QCOMPARE(ciType->value<char>(), '\n');
+  }
 }
 
 void TestExpressionParser::testTemplatesSimple() {
