@@ -52,6 +52,7 @@
 #include <language/duchain/dumpdotgraph.h>
 #include <language/duchain/dumpchain.h>
 #include <language/backgroundparser/parsejob.h>
+#include <language/backgroundparser/urlparselock.h>
 #include "cppeditorintegrator.h"
 #include "declarationbuilder.h"
 #include "usebuilder.h"
@@ -71,33 +72,6 @@
 
 using namespace KDevelop;
 
-///Facilities to prevent multiple parse-jobs from processing the same url.
-QMutex urlParseMutex;
-QMap<IndexedString, QPair<Qt::HANDLE, uint> > parsingUrls;
-
-UrlParseLock::UrlParseLock(IndexedString url) : m_url(url) {
-  QMutexLocker lock(&urlParseMutex);
-  while(parsingUrls.contains(m_url) && parsingUrls[m_url].first != QThread::currentThreadId()) {
-    //Wait here until no other thread is updating parsing the url
-    lock.unlock();
-    sleep(1);
-    lock.relock();
-  }
-  if(parsingUrls.contains(m_url))
-    ++parsingUrls[m_url].second;
-  else
-    parsingUrls.insert(m_url, qMakePair(QThread::currentThreadId(), 1u));
-}
-
-UrlParseLock::~UrlParseLock() {
-  QMutexLocker lock(&urlParseMutex);
-  Q_ASSERT(parsingUrls.contains(m_url));
-  Q_ASSERT(parsingUrls[m_url].first == QThread::currentThreadId());
-  --parsingUrls[m_url].second;
-  if(parsingUrls[m_url].second == 0)
-    parsingUrls.remove(m_url);
-}
-
 bool importsContext(const QVector<DUContext::Import>& contexts, const DUContext* context) {
   foreach(const DUContext::Import &listCtx, contexts)
     if(listCtx.context(0) && listCtx.context(0)->imports(context))
@@ -261,7 +235,7 @@ void CPPParseJob::mergeDefines(CppPreprocessEnvironment& env) const
 const QList<IndexedString>& CPPParseJob::includePaths() const {
     //If a lock was held here, we would get deadlocks
     if( ICore::self()->shuttingDown() )
-      return QList<IndexedString>();
+      return m_includePaths;
     
     if( masterJob() == this ) {
         if( !m_includePathsComputed ) {
@@ -274,7 +248,7 @@ const QList<IndexedString>& CPPParseJob::includePaths() const {
             {
               if(ICore::self()->shuttingDown())
               {
-                return QList<IndexedString>();
+                return m_includePaths;
               }
             }
             m_waitForIncludePathsMutex.unlock();
@@ -793,8 +767,8 @@ void CPPInternalParseJob::run()
         if(keepAST)
         {
           kDebug() << "AST Is being kept for" << parentJob()->document().toUrl();
-          parentJob()->parseSession()->setASTNodeParents();
           contentContext->setAst(IAstContainer::Ptr( parentJob()->parseSession().data() ));
+          parentJob()->parseSession()->setASTNodeParents();
         }
 
         else
@@ -952,6 +926,8 @@ void CPPInternalParseJob::run()
         }
       }
     }*/
+
+   parentJob()->cleanupSmartRevision();
 }
 
 void CPPParseJob::processDelayedImports() {
