@@ -184,10 +184,10 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   ADD_TOKEN(reinterpret_cast);
   ADD_TOKEN(return);
   ADD_TOKEN(short);
-  ADD_TOKEN(signals);
+  ADD_TOKEN(__qt_signals__);
   ADD_TOKEN(signed);
   ADD_TOKEN(sizeof);
-  ADD_TOKEN(slots);
+  ADD_TOKEN(__qt_slots__);
   ADD_TOKEN(static);
   ADD_TOKEN(static_cast);
   ADD_TOKEN(struct);
