@@ -102,10 +102,10 @@ enum TOKEN_KIND
     Token_scope,
     Token_shift,
     Token_short,
-    Token_signals,
+    Token___qt_signals__,
     Token_signed,
     Token_sizeof,
-    Token_slots,
+    Token___qt_slots__,
     Token_static,
     Token_static_cast,
     Token_string_literal,
