@@ -87,6 +87,7 @@
 #include <cmakeconfig.h>
 
 #include <language/highlighting/codehighlighting.h>
+#include <interfaces/iruncontroller.h>
 
 using namespace KDevelop;
 
@@ -152,6 +153,8 @@ CMakeManager::CMakeManager( QObject* parent, const QVariantList& )
     m_highlight = new KDevelop::CodeHighlighting(this);
 
     new CodeCompletion(this, new CMakeCodeCompletionModel(this), name());
+    
+    connect(ICore::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)), SLOT(projectClosing(KDevelop::IProject*)));
 }
 
 CMakeManager::~CMakeManager()
@@ -627,7 +630,7 @@ bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
         folder->project()->reloadModel();
     } else {
         CMakeFolderItem* former=item->formerParent();
-        QStandardItem* parent=item->parent();
+        ProjectFolderItem* parent=static_cast<ProjectFolderItem*>(item->parent());
         KUrl url=item->url();
         IProject* project=item->project();
 
@@ -635,8 +638,7 @@ bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
         CMakeFolderItem* fi=new CMakeFolderItem(project, url.toLocalFile(), 0);
 
         fi->setFormerParent(former);
-        parent->appendRow(fi);
-        reimport(fi);
+        reimport(fi, parent->url());
     }
     return true;
 }
@@ -726,54 +728,70 @@ KDevelop::IProjectBuilder * CMakeManager::builder(KDevelop::ProjectFolderItem *)
     vm->remove("CMAKE_CURRENT_BINARY_DIR");
 }*/
 
-//Copied from ImportJob
-void CMakeManager::reimport(CMakeFolderItem* fi)
+void CMakeManager::reimport(KDevelop::ProjectFolderItem* fi, const KUrl& parent)
 {
-    QQueue< QList<KDevelop::ProjectFolderItem*> > workQueue;
-    QList<KDevelop::ProjectFolderItem*> initial;
-    initial.append( fi );
-    workQueue.enqueue( initial );
+    Q_ASSERT(!isReloading(fi->project()));
+    
+    KJob *job=createImportJob(fi);
+    job->setProperty("parent", QUrl(parent));
+    
+    QMutexLocker locker(&m_busyProjectsMutex);
+    m_busyProjects[job]=fi;
+    
+    connect( job, SIGNAL( result( KJob* ) ), this, SLOT( reimportDone( KJob* ) ) );
+    ICore::self()->runController()->registerJob( job );
+}
 
-    while( workQueue.count() > 0 )
+void CMakeManager::reimportDone(KJob* job)
+{
+    QMutexLocker locker(&m_busyProjectsMutex);
+    Q_ASSERT(m_busyProjects.contains(job));
+    ProjectFolderItem* it=m_busyProjects[job];
+    
+    QUrl parentUrl=job->property("parent").toUrl();
+    
+    QList<ProjectFolderItem*> folders=it->project()->foldersForUrl(parentUrl);
+    
+    if(!folders.isEmpty()) //If it was not removed while reparsing
     {
-        QList<KDevelop::ProjectFolderItem*> front = workQueue.dequeue();
-        Q_FOREACH( KDevelop::ProjectFolderItem* _item, front )
-        {
-            QList<KDevelop::ProjectFolderItem*> workingList = parse( _item );
-            if( workingList.count() > 0 )
-                workQueue.enqueue( workingList );
-        }
+        Q_ASSERT(folders.size()==1);
+        
+        folders.first()->appendRow(m_busyProjects[job]);
     }
+    m_busyProjects.remove(job);
+}
+
+bool CMakeManager::isReloading(IProject* p)
+{
+    QMutexLocker locker(&m_busyProjectsMutex);
+    if(!p->isReady())
+        return true;
+    
+    foreach(KDevelop::ProjectFolderItem* it, m_busyProjects) {
+        if(it->project()==p)
+            return true;
+    }
+    return false;
 }
 
 void CMakeManager::dirtyFile(const QString & dirty)
 {
-    KUrl dirtyFile(dirty);
-    KUrl dir(dirtyFile.upUrl());
+    const KUrl dirtyFile(dirty);
     IProject* p=ICore::self()->projectController()->findProjectForUrl(dirtyFile);
 
+    if(p && isReloading(p))
+        return;
+    
     if(p && dirtyFile.fileName() == "CMakeLists.txt")
     {
+        QMutexLocker locker(&m_reparsingMutex); //Maybe we should have a mutex per project
+        
         QList<ProjectFileItem*> files=p->filesForUrl(dirtyFile);
         kDebug(9032) << dirtyFile << "is dirty" << files.count();
 
-        // Debug output as apparently the Q_ASSERT after this is sometimes hitting
-        // See https://bugs.kde.org/show_bug.cgi?id=187335
-        if( files.count() > 1 ) {
-            foreach(ProjectFileItem* item, files) {
-                kDebug() << "item:" << item << item->url() << item->text() << item->parent()->type() << item->parent()->text();
-            }
-        }
-
         Q_ASSERT(files.count()==1);
-        CMakeFolderItem *it=static_cast<CMakeFolderItem*>(files.first()->parent());
-
-        KDevelop::IProject* proj=it->project();
-        KUrl projectBaseUrl=proj->projectItem()->url();
-        projectBaseUrl.adjustPath(KUrl::AddTrailingSlash);
-
-        kDebug(9032) << "reload:" << dir << projectBaseUrl << (dir!=projectBaseUrl);
-        if(dir!=projectBaseUrl)
+        CMakeFolderItem *folderItem=static_cast<CMakeFolderItem*>(files.first()->parent());
+        if(folderItem!=p->projectItem())
         {
 #if 0
             KUrl relative=KUrl::relativeUrl(projectBaseUrl, dir);
@@ -786,12 +804,11 @@ void CMakeManager::dirtyFile(const QString & dirty)
                 parseOnly(proj, current);
             }
 #endif
-            reload(it);
+            reload(folderItem);
         }
         else
         {
-    //         qDebug() << "reloading";
-            reload(proj->projectItem());
+            reload(p->projectItem());
         }
     }
     else if(dirty.endsWith(".cmake"))
@@ -802,7 +819,7 @@ void CMakeManager::dirtyFile(const QString & dirty)
                 reload(project->projectItem());
         }
     }
-    else if(QFileInfo(dirty).isDir())
+    else if(p && QFileInfo(dirty).isDir())
     {
         QList<ProjectFolderItem*> folders=p->foldersForUrl(dirty);
         Q_ASSERT(folders.isEmpty() || folders.size()==1);
@@ -1019,7 +1036,7 @@ KDevelop::ProjectFolderItem* CMakeManager::addFolder( const KUrl& folder, KDevel
 
 bool CMakeManager::removeFolder( KDevelop::ProjectFolderItem* it)
 {
-    if ( !KDevelop::removeUrl(it->url(), true) ) {
+    if ( !KDevelop::removeUrl(it->project(), it->url(), true) ) {
         return false;
     }
     KUrl lists=it->url().upUrl();
@@ -1107,7 +1124,7 @@ bool followUses(KTextEditor::Document* doc, SimpleRange r, const QString& name,
 
 bool CMakeManager::removeFile( KDevelop::ProjectFileItem* it)
 {
-    if ( !KDevelop::removeUrl(it->url(), false) ) {
+    if ( !KDevelop::removeUrl(it->project(), it->url(), false) ) {
         return false;
     }
 
@@ -1365,4 +1382,13 @@ bool CMakeManager::renameFolder(ProjectFolderItem* _it, const KUrl& newUrl)
     return ret;
 }
 
+void CMakeManager::projectClosing(IProject* p)
+{
+    m_modulePathPerProject.remove(p);
+    m_varsPerProject.remove(p); 
+    m_macrosPerProject.remove(p);
+    m_watchers.remove(p);
+    m_projectCache.remove(p);
+}
+
 #include "cmakemanager.moc"
