@@ -37,6 +37,7 @@
 #include "icmakemanager.h"
 #include "cmakeprojectvisitor.h"
 
+class QStandardItem;
 class QDir;
 class QObject;
 class CMakeHighlighting;
@@ -114,16 +115,20 @@ public:
     virtual const KDevelop::ICodeHighlighting* codeHighlighting() const;
     virtual QWidget* specialLanguageObjectNavigationWidget(const KUrl& url, const KDevelop::SimpleCursor& position);
 
-public slots:
+private slots:
     void dirtyFile(const QString& file);
 
     void jumpToDeclaration();
+    void projectClosing(KDevelop::IProject*);
+    void reimportDone(KJob* job);
 
 private:
-    void reimport(CMakeFolderItem*);
+    void reimport(KDevelop::ProjectFolderItem* fi, const KUrl& parent);
     CacheValues readCache(const KUrl &path) const;
-
+    bool isReloading(KDevelop::IProject* p);
     
+    QMutex m_reparsingMutex;
+    QMutex m_busyProjectsMutex;
     KDevelop::ReferencedTopDUContext initializeProject(KDevelop::IProject* project, const KUrl& baseUrl);
     
     KDevelop::ReferencedTopDUContext includeScript(const QString& File, KDevelop::IProject * project,
@@ -136,6 +141,8 @@ private:
     QMap<KDevelop::IProject*, CacheValues> m_projectCache;
     QMap<KUrl, KDevelop::ProjectFolderItem*> m_pending;
     
+    QMap<KJob*, KDevelop::ProjectFolderItem*> m_busyProjects;
+    
     KDevelop::ICodeHighlighting *m_highlight;
     
     QList<KDevelop::ProjectBaseItem*> m_clickedItems;
