@@ -1292,6 +1292,12 @@ int CMakeProjectVisitor::visit(const ExecuteProcessAst *exec)
             kDebug(9042) << "error: failed to execute:" << p;
         }
     }
+    
+    if(!procs.isEmpty() && !exec->resultVariable().isEmpty())
+    {
+        kDebug(9042) << "execution returned: " << exec->resultVariable() << " = " << procs.last()->exitCode();
+        m_vars->insert(exec->resultVariable(), QStringList(QString::number(procs.last()->exitCode())));
+    }
 
     //FIXME: remove condition when filtering bad output
     if(!procs.isEmpty() && !exec->outputVariable().isEmpty())
@@ -1658,17 +1664,8 @@ int CMakeProjectVisitor::visit(const StringAst *sast)
                 {
                     foreach(const QString& in, sast->input())
                     {
-                        rx.indexIn(in);
-                        QStringList info = rx.capturedTexts();
-                        
-                        QString tmp = sast->replace();
-                        for(int i = 1; i < info.count(); i++)
-                        {
-                            tmp.replace(QString("\\%1").arg(i), info.at(i));
-                        }
-                        
-                        QString toret=in;
-                        res.append(toret.replace(rx, tmp));
+                        // QString() is required to get rid of the const
+                        res.append(QString(in).replace(rx, sast->replace()));
                     }
                 }
                     break;
