@@ -69,6 +69,11 @@ void CustomMakeTreeSynchronizer::filesCreated( const KUrl::List &files,
 {
     Q_FOREACH( const KUrl& _file, files )
     {
+        //TODO: make filtering generic
+        if ( _file.fileName().endsWith('~') || _file.fileName().endsWith(".o") )
+        {
+            continue;
+        }
         KDevelop::ProjectFileItem *newitem = new KDevelop::ProjectFileItem(
             parentFolder->project(), _file, parentFolder );
         // if Makefile, parse new targets and add to watcher
